# /packages/intranet-budget/lib/budget-tree_component.tcl
#
# Copyright (C) 2012-2020 ]project-open[
#
# All rights reserved. Please check
# https://www.project-open.com/license/ for details.

# ----------------------------------------------------------------------
# 
# ---------------------------------------------------------------------

# The following variables are expected in the environment
# defined by the calling /tcl/*.tcl libary:
#	project_id
#	diagram_title
#	diagram_width
#	diagram_height

if {![info exists diagram_width]} { set diagram_width 1200 }
if {![info exists diagram_height]} { set diagram_height 400 }
if {![info exists diagram_title]} { set diagram_title "" }
if {![info exists locale]} { set locale "" }
set main_project_id $project_id

set show_diagram_p 1
set show_debug_p 0
if {"" == $locale} { set locale [lang::user::locale -user_id [ad_conn user_id]] }

# Create a random ID for the budget_tree
set budget_tree_rand [expr {round(rand() * 100000000.0)}]
set budget_tree_id "budget_tree_$budget_tree_rand"
set senior_manager_group_id [im_profile_senior_managers]

set data_list {}

# Cost Types
set cost_type_ids [im_budget_item_rollup_cost_type_ids]
set cti_columns {}
foreach cti $cost_type_ids {
    set cost_type_l10n [im_category_from_id -translate_p 1 $cti]
    ns_log Notice "xxx: cost_type_l10n=$cost_type_l10n"
    set cost_type_english [db_string cost_type "select category from im_categories where category_id = :cti" -default "Category_$cti"]
    ns_log Notice "xxx: cost_type_english=$cost_type_english"
    regsub -all {[^a-zA-Z0-9\.\-\_]} $cost_type_english "_" cost_type_key
    ns_log Notice "xxx: cost_type_key=$cost_type_key"
    set tooltip_msg [lang::message::lookup $locale intranet-budget.Help_column_$cost_type_key "\
    <b>%cost_type_l10n%</b>:\
    <br>Actual values for `%cost_type_l10n%`.\
    <br>Please see the Help menu on how to\
    <br>configure automatic classification of\
    <br>these costs."]
    set tooltip "'$tooltip_msg'"

    # ad_return_complaint 1 "en='$cost_type_english', key='$cost_type_key', l10n='$cost_type_l10n', tooltip=$tooltip"

    lappend cti_columns "\t\t{text:'$cost_type_l10n', coltype:'actuals', width:50, flex:1, align:'right', dataIndex:'cost_type_$cti', sortable:false, tooltip:$tooltip},"
}
set cost_type_actuals_columns [join $cti_columns "\n"]

# Create a debug JSON object that controls logging verbosity
set debug_default "default 0"
set debug_list [parameter::get_from_package_key -package_key "intranet-gantt-editor" -parameter DebugHash -default $debug_default]
array set debug_hash $debug_list
set debug_json_list {}
foreach id [array names debug_hash] { lappend debug_json_list "'$id': $debug_hash($id)" }
set debug_json "{\n\t[join $debug_json_list ",\n\t"]\n}"

